<?php
/**
 * @version		$Id: registration.php 20196 2011-01-09 02:40:25Z ian $
 * @package		Joomla.Site
 * @subpackage	com_users
 * @copyright	Copyright (C) 2005 - 2011 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

require_once JPATH_COMPONENT.'/controller.php';

/**
 * Registration controller class for Users.
 *
 * @package		Joomla.Site
 * @subpackage	com_users
 * @since		1.6
 */
class UsersControllerRegistration extends UsersController
{
	/**
	 * Method to activate a user.
	 *
	 * @return	boolean		True on success, false on failure.
	 * @since	1.6
	 */
	public function activate()
	{	
		$user		= JFactory::getUser();
		$uParams	= JComponentHelper::getParams('com_users');

		// If the user is logged in, return them back to the homepage.
		if ($user->get('id')) {
			$this->setRedirect('index.php');
			return true;
		}

		// If user registration or account activation is disabled, throw a 403.
		if ($uParams->get('useractivation') == 0 || $uParams->get('allowUserRegistration') == 0) {
			JError::raiseError(403, JText::_('JLIB_APPLICATION_ERROR_ACCESS_FORBIDDEN'));
			return false;
		}

		$model = $this->getModel('Registration', 'UsersModel');
		$token = JRequest::getVar('token', null, 'request', 'alnum');

		// Check that the token is in a valid format.
		if ($token === null || strlen($token) !== 32) {
			JError::raiseError(403, JText::_('JINVALID_TOKEN'));
			return false;
		}

		// Attempt to activate the user.
		$return = $model->activate($token);

		// Check for errors.
		if ($return === false) {
			// Redirect back to the homepage.
			$this->setMessage(JText::sprintf('COM_USERS_REGISTRATION_SAVE_FAILED', $model->getError()), 'warning');
			$this->setRedirect('index.php');
			return false;
		}

		$useractivation = $uParams->get('useractivation');

		// Redirect to the login screen.
		if ($useractivation == 0)
		{
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_SAVE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));
		}
		else if ($useractivation == 1)
		{
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_ACTIVATE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));
		}
		else if ($return->getParam('activate'))
		{
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_VERIFY_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=registration&layout=complete', false));
		}
		else
		{
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_ADMINACTIVATE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=registration&layout=complete', false));
		}
		
		$config	= &JComponentHelper::getParams('com_ajaxregister');
		
		$autologin = $config->get('autologin', 0);
		if ($autologin && $return) {
			$redirect_url = $config->get('redirect_url', '');
			
			if ($redirect_url!='' && substr($redirect_url, 0, 4)!='http') {
				$redirect_url = JURI::root() . $redirect_url;
			} else {
				$redirect_url = 'index.php?option=com_users&view=profile';
			}
			
			$display_message = $config->get('display_message', 1);
			
			//perform the login action
			$user = JUser::getInstance($return->id); // Bring this in line with the rest of the system
			$response->username = $user->username;
			$response->email = $user->email;
			$response->fullname = $user->name;
			$response->status = 1;
			$response->error_message = '';

			// Import the user plugin group
			JPluginHelper::importPlugin('user');
			
			// OK, the credentials are authenticated.  Lets fire the onLogin event
			$app = JFactory::getApplication();
			$option = array('action'=>'core.login.site');
			$results = $app->triggerEvent('onUserLogin', array((array)$response, $option));
			
			$message = '';
			if ($display_message) {
				$message = JText::_( 'AJAXREG_ACTIVATE_COMPLETE_LOGIN' );
			}
		
			$this->setRedirect($redirect_url, $message);
			
		}
		
		return true;
	}

	/**
	 * Method to register a user.
	 *
	 * @return	boolean		True on success, false on failure.
	 * @since	1.6
	 */
	public function register()
	{
		// Check for request forgeries.
		JRequest::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// If registration is disabled - Redirect to login page.
		if(JComponentHelper::getParams('com_users')->get('allowUserRegistration') == 0) {
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));
			return false;
		}

		// Initialise variables.
		$app	= JFactory::getApplication();
		$model	= $this->getModel('Registration', 'UsersModel');

		// Get the user data.
		$requestData = JRequest::getVar('jform', array(), 'post', 'array');
		
		$config	= &JComponentHelper::getParams('com_ajaxregister');
		
		if (!$config->get('email_confirm') && isset($requestData['email1'])) {
			$requestData['email2'] = $requestData['email1'];
		}

		if ($config->get('email_as_username')) {
			$requestData['username'] = $requestData['email1'];
		}
		
		// Check if disclaimer accept needed
		if($config->get('display_disclaimer_checkbox')==0) {
			$requestData['accept'] = 'yes';
		}
		
		// Check for banned username/IP
		$blocks_usernames = $config->get('blocks_usernames', '');
		if($blocks_usernames!='') {
			if (stristr($blocks_usernames,',')) {
				$blocks_usernames = explode(',', $blocks_usernames);
			} else {
				$blocks_usernames = explode("\n", $blocks_usernames);
			}
			foreach($blocks_usernames as $block_username) {
				if (strcasecmp(trim($user->username), trim($block_username))==0) {
					JError::raiseWarning( 403, JText::_('AJAXREG_USERNAME_BLOCKED') );
					$this->register();
					return;
				}
			}
		}
		$blocks_ips = $config->get('blocks_ips', '');
		if($config->get('blocks_ips')!='') {
			require_once(JPATH_COMPONENT.DS.'libraries'.DS.'ip_in_range.php');
			if (stristr($blocks_ips,',')) {
				$blocks_ips = explode(',', $blocks_ips);
			} else {
				$blocks_ips = explode("\n", $blocks_ips);
			}
			foreach($blocks_ips as $block_ip) {
				if ( ip_in_range($_SERVER['REMOTE_ADDR'], trim($block_ip)) ) {
					JError::raiseWarning( 403, JText::_('AJAXREG_IP_BLOCKED') );
					$this->register();
					return;
				}
			}
		}

		// CAPTCHA
		if($config->get('captcha_type') == 3) {
			// Queations and answers
			for ($i=1; $i<=5; $i++) {
				$response = JRequest::getString('answer_'.$i);
				if ($response) {
					$question_id = $i;
					break;
				}
			}
			$challenge = $config->get('answer_'.$question_id, '');
			// validate
			if ( strtolower(trim($challenge)) != strtolower(trim($response)) ) {
				JError::raiseWarning( 403, JText::_('AJAXREG_ANSWER_WRONG') );
				$this->register();
				return;
			}
		} else if($config->get('captcha_type') == 2) {
			// reCAPTCHA
			$challenge = JRequest::getVar('recaptcha_challenge_field', null);
			$user =& JFactory::getUser();
			$solved = $user->get($challenge, 0);
			// if not already solved
			if ($solved) {
				$user->set($challenge, null);
			} else {
				// get a reCAPTCHA object
				require_once(JPATH_COMPONENT.DS.'libraries'.DS.'captcha'.DS.'recaptcha.php');
				$recaptcha = JXRecaptcha::getInstance();

				// set the API keys for reCAPTCHA
				$recaptcha->setKeyPair($config->get('recaptcha_public'), $config->get('recaptcha_private'));

				// validate the captcha
				if (!$recaptcha->checkCaptcha()) {
					JError::raiseWarning( 403, JText::_('AJAXREG_RECAPTCHA_FAILED') );
					$this->register();
					return;
				}
			}
		} else if($config->get('captcha_type') == 1) {
			// Image CAPTCHA
			require_once(JPATH_COMPONENT.DS.'libraries'.DS.'captcha'.DS.'captcha.php');
			$captcha = &JXCaptcha::getInstance('image', array(
					'filePath'	=> JPATH_SITE.DS.'tmp'
				)
			);

			// get the list of CAPTCHA tests from the session and verify that they do exist
			$captchas = $app->getUserState('jxcaptcha.captcha');
			if (empty($captchas)) {
				//return new JException('Captcha image has gone stale', 500);
				JError::raiseWarning( 500, 'Captcha image has gone stale' );
				$this->register();
				return;
			}

			// get the post fields from the request
			$post = JRequest::get('post');
			
			$validate = false;

			// iterate over the CAPTCHA tests from the session to validate them
			foreach ($captchas as $item)
			{
				// make sure that something was posted for this CAPTCHA test
				if (isset($post[$item['id']])) {
					// make sure that the posted value passes CAPTCHA validation for the test
					if ($captcha->validate($item['id'], $post[$item['id']], false)) {
						$validate = true;
					}
				}
			}
			
			if (!$validate) {
				//return new JException('Captcha validation failed', 403);
				JError::raiseWarning( 403, JText::_('AJAXREG_CAPTCHA_FAILED') );
				$this->register();
				return;
			}
			
			$captcha->clean();
		}
		
		// Validate the posted data.
		$form	= $model->getForm();
		if (!$form) {
			JError::raiseError(500, $model->getError());
			return false;
		}
		$data	= $model->validate($form, $requestData);

		// Check for validation errors.
		if ($data === false) {
			// Get the validation messages.
			$errors	= $model->getErrors();

			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
				if (JError::isError($errors[$i])) {
					$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				} else {
					$app->enqueueMessage($errors[$i], 'warning');
				}
			}

			// Save the data in the session.
			$app->setUserState('com_users.registration.data', $requestData);

			// Redirect back to the registration screen.
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=registration', false));
			return false;
		}

		// Attempt to save the data.
		$return	= $model->register($data);
		
		$display_message = $config->get('display_message', 1);

		// Check for errors.
		if ($return === false) {
			// Save the data in the session.
			$app->setUserState('com_users.registration.data', $data);

			// Redirect back to the edit screen.
			$this->setMessage(JText::sprintf('COM_USERS_REGISTRATION_SAVE_FAILED', $model->getError()), 'warning');
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=registration', false));
			if ($display_message==0) {
				$this->setMessage('');
			}
			return false;
		}

		// Flush the data from the session.
		$app->setUserState('com_users.registration.data', null);

		// Redirect to the profile screen.
		if ($return === 'adminactivate'){
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_COMPLETE_VERIFY'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=registration&layout=complete', false));
		} else if ($return === 'useractivate') {
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_COMPLETE_ACTIVATE'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=registration&layout=complete', false));
		} else {
			$this->setMessage(JText::_('COM_USERS_REGISTRATION_SAVE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));
		}
		
		if ($display_message==0) {
			$this->setMessage('');
		}
		
		$redirect_url = $config->get('redirect_url', '');
		
		if ($redirect_url!='' && substr($redirect_url, 0, 4)!='http') {
			$redirect_url = JURI::root() . $redirect_url;
		}
		
		$autologin = $config->get('autologin', 0);
		
		$usersConfig = &JComponentHelper::getParams( 'com_users' );
		$useractivation = $usersConfig->get('useractivation');
		
		// Auto-login
		if ($autologin && !$useractivation) {			
			$options = array();

			// Get the log in credentials.
			$credentials = array();
			$credentials['username'] = $data['username'];
			$credentials['password'] = $data['password1'];

			// Perform the log in.
			$error = $app->login($credentials, $options);
			$this->setRedirect('index.php?option=com_users&view=profile', false);
		}
		
		if ($redirect_url!='') {
			$this->setRedirect($redirect_url, false);
		}

		return true;
	}
}