<?php
/**
 * @version		$Id: controller.php 11215 2008-10-26 02:25:51Z ian $
 * @package		Joomla
 * @subpackage	Content
 * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

//jimport('joomla.application.component.helper');
require_once (JPATH_SITE.DS.'components'.DS.'com_user'.DS.'controller.php');

/**
 * User Component Controller
 *
 * @package		Joomla
 * @subpackage	Weblinks
 * @since 1.5
 */
class UserControllerExt extends UserController
{
	/**
	 * Save user registration and notify users and admins if required
	 * @return void
	 */
	function register_save()
	{
		global $mainframe;

		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		// Get required system objects
		$user 		= clone(JFactory::getUser());
		$pathway 	=& $mainframe->getPathway();
		$config		=& JFactory::getConfig();
		$authorize	=& JFactory::getACL();
		$document   =& JFactory::getDocument();

		// If user registration is not allowed, show 403 not authorized.
		$usersConfig = &JComponentHelper::getParams( 'com_users' );
		if ($usersConfig->get('allowUserRegistration') == '0') {
			JError::raiseError( 403, JText::_( 'Access Forbidden' ));
			return;
		}

		// Initialize new usertype setting
		$newUsertype = $usersConfig->get( 'new_usertype' );
		if (!$newUsertype) {
			$newUsertype = 'Registered';
		}

		// Bind the post array to the user object
		if (!$user->bind( JRequest::get('post'), 'usertype' )) {
			JError::raiseError( 500, $user->getError());
		}
		
		$config	= &JComponentHelper::getParams('com_ajaxregister');
		
		if ($config->get('email_as_username')) {
			$user->username = $user->email;
		}
		
		// Save the fields in case the registration fails
		$user2 =& JFactory::getUser();
		$user2->set('name', $user->name);
		$user2->set('username', $user->username);
		$user2->set('email', $user->email);

		// Set some initial user values
		$user->set('id', 0);
		$user->set('usertype', $newUsertype);
		$user->set('gid', $authorize->get_group_id( '', $newUsertype, 'ARO' ));

		$date =& JFactory::getDate();
		$user->set('registerDate', $date->toMySQL());

		// If user activation is turned on, we need to set the activation information
		$useractivation = $usersConfig->get( 'useractivation' );
		if ($useractivation == '1')
		{
			jimport('joomla.user.helper');
			$user->set('activation', JUtility::getHash( JUserHelper::genRandomPassword()) );
			$user->set('block', '1');
		}
		
		// Check if disclaimer accepted
		if($config->get('display_disclaimer')==1 && $config->get('display_disclaimer_checkbox')==1) {
			$accept = JRequest::getVar('accept', 'no');
			if ($accept!='yes') {
				//return new JException('Captcha validation failed', 403);
				JError::raiseWarning( 403, JText::_('AJAXREG_DISCLAIMER_FAILED') );
				$this->register();
				return;
			}
		}
		
		// Check for banned username/IP
		$blocks_usernames = $config->get('blocks_usernames', '');
		if($blocks_usernames!='') {
			if (stristr($blocks_usernames,',')) {
				$blocks_usernames = explode(',', $blocks_usernames);
			} else {
				$blocks_usernames = explode("\n", $blocks_usernames);
			}
			foreach($blocks_usernames as $block_username) {
				if (strcasecmp(trim($user->username), trim($block_username))==0) {
					JError::raiseWarning( 403, JText::_('AJAXREG_USERNAME_BLOCKED') );
					$this->register();
					return;
				}
			}
		}
		$blocks_ips = $config->get('blocks_ips', '');
		if($config->get('blocks_ips')!='') {
			require_once(JPATH_COMPONENT.DS.'libraries'.DS.'ip_in_range.php');
			if (stristr($blocks_ips,',')) {
				$blocks_ips = explode(',', $blocks_ips);
			} else {
				$blocks_ips = explode("\n", $blocks_ips);
			}
			foreach($blocks_ips as $block_ip) {
				if ( ip_in_range($_SERVER['REMOTE_ADDR'], trim($block_ip)) ) {
					JError::raiseWarning( 403, JText::_('AJAXREG_IP_BLOCKED') );
					$this->register();
					return;
				}
			}
		}

		// CAPTCHA
		if($config->get('captcha_type') == 3) {
			// Queations and answers
			for ($i=1; $i<=5; $i++) {
				$response = JRequest::getString('answer_'.$i);
				if ($response) {
					$question_id = $i;
					break;
				}
			}
			$challenge = $config->get('answer_'.$question_id, '');
			// validate
			if ( strtolower(trim($challenge)) != strtolower(trim($response)) ) {
				JError::raiseWarning( 403, JText::_('AJAXREG_ANSWER_WRONG') );
				$this->register();
				return;
			}
		} else if($config->get('captcha_type') == 2) {
			// reCAPTCHA
			$challenge = JRequest::getVar('recaptcha_challenge_field', null);
			$solved = $user2->get($challenge, 0);
			// if not already solved
			if ($solved) {
				$user2->set($challenge, null);
			} else {
				// get a reCAPTCHA object
				require_once(JPATH_COMPONENT.DS.'libraries'.DS.'captcha'.DS.'recaptcha.php');
				$recaptcha = JXRecaptcha::getInstance();

				// set the API keys for reCAPTCHA
				$recaptcha->setKeyPair($config->get('recaptcha_public'), $config->get('recaptcha_private'));

				// validate the captcha
				if (!$recaptcha->checkCaptcha()) {
					JError::raiseWarning( 403, JText::_('AJAXREG_RECAPTCHA_FAILED') );
					$this->register();
					return;
				}
			}
		} else if($config->get('captcha_type') == 1) {
			// Image CAPTCHA
			require_once(JPATH_COMPONENT.DS.'libraries'.DS.'captcha'.DS.'captcha.php');
			$captcha = &JXCaptcha::getInstance('image', array(
					'filePath'	=> JPATH_SITE.DS.'tmp'
				)
			);

			// get the list of CAPTCHA tests from the session and verify that they do exist
			$captchas = $mainframe->getUserState('jxcaptcha.captcha');
			if (empty($captchas)) {
				//return new JException('Captcha image has gone stale', 500);
				JError::raiseWarning( 500, 'Captcha image has gone stale' );
				$this->register();
				return;
			}

			// get the post fields from the request
			$post = JRequest::get('post');
			
			$validate = false;

			// iterate over the CAPTCHA tests from the session to validate them
			foreach ($captchas as $item)
			{
				// make sure that something was posted for this CAPTCHA test
				if (isset($post[$item['id']])) {
					// make sure that the posted value passes CAPTCHA validation for the test
					if ($captcha->validate($item['id'], $post[$item['id']], false)) {
						$validate = true;
					}
				}
			}
			
			if (!$validate) {
				//return new JException('Captcha validation failed', 403);
				JError::raiseWarning( 403, JText::_('AJAXREG_CAPTCHA_FAILED') );
				$this->register();
				return;
			}
			
			$captcha->clean();
		}

		// If there was an error with registration, set the message and display form
		if ( !$user->save() )
		{
			JError::raiseWarning('', JText::_( $user->getError()));
			$this->register();
			return false;
		}

		// Send registration confirmation mail
		$password = JRequest::getString('password', '', 'post', JREQUEST_ALLOWRAW);
		$password = preg_replace('/[\x00-\x1F\x7F]/', '', $password); //Disallow control chars in the email
		UserController::_sendMail($user, $password);
	
		// Reset the defaults
		$user2->set('name', null);
		$user2->set('username', null);
		$user2->set('email', null);

		// Everything went fine, set relevant message depending upon user activation state and display message
		if ( $useractivation == 1 ) {
			$message  = JText::_( 'REG_COMPLETE_ACTIVATE' );
		} else {
			$message = JText::_( 'REG_COMPLETE' );
		}
		
		$config	= &JComponentHelper::getParams('com_ajaxregister');
		$display_message = $config->get('display_message', 1);
		if ($display_message==0) {
			$message = '';
		}
		$redirect_url = JURI::root() . $config->get('redirect_url', '');
		
		$autologin = $config->get('autologin', 0);
		$useractivation = $usersConfig->get('useractivation');
		
		// Auto-login
		if ($autologin && !$useractivation) {
			$return = base64_encode($redirect_url);
			JRequest::setVar('return', $return, 'post');
			JRequest::setVar('username', $user->username, 'post');
			JRequest::setVar('passwd', $password, 'post');
			$this->login();
		} else {
			$this->setRedirect($redirect_url, $message);
		}
	}
	
	function activate()
	{
		global $mainframe;
		
		$db =& JFactory::getDBO();
		
		$activation = JRequest::getVar('activation', '', '', 'alnum' );
		$activation = $db->getEscaped( $activation );

		$query = 'SELECT `id`'
			. ' FROM `#__users`'
			. ' WHERE activation=' . $db->Quote( $activation )
			;
		$db->setQuery( $query );
		$result = $db->loadObject();
		
		parent::activate();
		
		$config	= &JComponentHelper::getParams('com_ajaxregister');
		
		$autologin = $config->get('autologin', 0);
		if ($autologin && $result) {
			$redirect_url = JURI::root() . $config->get('redirect_url', '');
			$display_message = $config->get('display_message', 1);
			
			//perform the login action
			$user = JUser::getInstance($result->id); // Bring this in line with the rest of the system
			$response->username = $user->username;
			$response->email = $user->email;
			$response->fullname = $user->name;
			$response->status = 1;
			$response->error_message = '';

			// Import the user plugin group
			JPluginHelper::importPlugin('user');
			
			// OK, the credentials are authenticated.  Lets fire the onLogin event
			$results = $mainframe->triggerEvent('onLoginUser', array((array)$response));
			
			$message = '';
			if ($display_message) {
				$message = JText::_( 'AJAXREG_ACTIVATE_COMPLETE_LOGIN' );
			}
		
			$this->setRedirect($redirect_url, $message);
		}
	}
}
?>
