<?php
/**
* @version		$Id: view.html.php 10752 2008-08-23 01:53:31Z eddieajau $
* @package		Joomla
* @subpackage	Registration
* @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* Joomla! is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

// Check to ensure this file is included in Joomla!
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.view');

/**
 * HTML View class for the Registration component
 *
 * @package		Joomla
 * @subpackage	Registration
 * @since 1.0
 */
class UserViewRegister extends JView
{
	function display($tpl = null)
	{
		global $mainframe;
		
		// Check if registration is allowed
		$usersConfig = &JComponentHelper::getParams( 'com_users' );
		if (!$usersConfig->get( 'allowUserRegistration' )) {
			JError::raiseError( 403, JText::_( 'Access Forbidden' ));
			return;
		}

		$pathway  =& $mainframe->getPathway();
		$document =& JFactory::getDocument();
		$params	= &$mainframe->getParams();

	 	// Page Title
		$menus	= &JSite::getMenu();
		$menu	= $menus->getActive();

		// because the application sets a default page title, we need to get it
		// right from the menu item itself
		if (is_object( $menu )) {
			$menu_params = new JParameter( $menu->params );
			if (!$menu_params->get( 'page_title')) {
				$params->set('page_title',	JText::_( 'Registration' ));
			}
		} else {
			$params->set('page_title',	JText::_( 'Registration' ));
		}
		$document->setTitle( $params->get( 'page_title' ) );

		$pathway->addItem( JText::_( 'New' ));

		// Load the form validation behavior
		//JHTML::_('behavior.formvalidation');
		JHTML::script('validate.js', 'components/com_ajaxregister/assets/js/');
		JHTML::stylesheet('validate.css', 'components/com_ajaxregister/assets/css/');

		$user =& JFactory::getUser();	
		$this->assignRef('user', $user);
		$this->assignRef('params', $params);
		
		$config	= &JComponentHelper::getParams('com_ajaxregister');
		
		// Clear button
		$this->assign( 'clear', $config->get('display_clear', 1) );
		
		// Use AJAX
		$this->assign( 'ajax', $config->get('enable_ajax', 1) );
		
		// Message type
		$this->assign( 'msg_type', $config->get('msg_type', 'text') );
		
		// Password strength
		$this->assign( 'password_strength', $config->get('password_strength', 1) );
		
		// Disclaimer textarea
		$this->assign( 'display_disclaimer', $config->get('display_disclaimer', 0) );
		// Disclaimer text
		$this->assign( 'disclaimer_text', $config->get('disclaimer_text', '') );
		// Disclaimer checkbox
		$this->assign( 'display_disclaimer_checkbox', $config->get('display_disclaimer_checkbox', 0) );
		
		// Autocomplete off
		$this->assign( 'autocomplete_off', $config->get('autocomplete_off', 0) );
		// Email as username
		$this->assign( 'email_as_username', $config->get('email_as_username', 0) );
		
		// CAPTCHA
		if ($config->get('captcha_type') == 3) {
			// Questions and answers
			$question = array();
			$question['id'] = rand(1,5);
			$question['text'] = $config->get('question_'.$question['id'], '');
			$this->assignRef( 'question', $question );
		} else if ($config->get('captcha_type') == 2) {
			// reCAPTCHA
			$this->assign( 'recaptcha_theme', $config->get('recaptcha_theme', 'clean') );
			$lang =& JFactory::getLanguage();
			$tag = $lang->getTag();
			$temp = explode('-',$tag);
			if( !empty($temp[0]) ) {
				$lang_code = $temp[0];
			} else {
				$lang_code = 'en';
			}
			$this->assign( 'recaptcha_lang', $lang_code );
			// build and set the reCAPTCHA test
			require_once(JPATH_COMPONENT.DS.'libraries'.DS.'captcha'.DS.'recaptcha.php');
			$recaptcha = &JXRecaptcha::getInstance();
			
			// set the API keys for reCAPTCHA
			$recaptcha->setKeyPair($config->get('recaptcha_public'), $config->get('recaptcha_private'));
			
			// render the reCAPTCHA output based on if the current URI is SSL encrypted or not
			$uri = &JFactory::getURI();
			$this->assign('recaptcha', $recaptcha->renderCaptcha($uri->isSSL()));
		} else if ($config->get('captcha_type') == 1) {
			// Image CAPTCHA
			$captcha_format = $config->get('captcha_format', 'png');
			$captcha_width = $config->get('captcha_width', 100);
			$captcha_height = $config->get('captcha_height', 40);
			$captcha_font_min = $config->get('captcha_font_min', 11);
			$captcha_font_max = $config->get('captcha_font_max', 14);
			// build and set the built-in CAPTCHA test
			require_once(JPATH_COMPONENT.DS.'libraries'.DS.'captcha'.DS.'captcha.php');
			$captcha = &JXCaptcha::getInstance('image', array(
					'filePath'	=> JPATH_SITE.DS.'tmp',
					'format'	=> $captcha_format,
					'width'		=> $captcha_width,
					'height'	=> $captcha_height,
					'minFont'	=> $captcha_font_min,
					'maxFont'	=> $captcha_font_max
				)
			);
			// Initialize the captcha object
			if (!$captcha->test() || !$captcha->initialize()) {
				// either the test failed or the object could not initialize, raise an error and return
				JError::raiseWarning(500, $captcha->getError());
			}
			// create a CAPTCHA test and set the object into the view
			$captcha->clean();
			if (is_array($return = $captcha->create())) {
				$this->assignRef( 'captcha', $return );
			}
		}

		$allow_override = $config->get('allow_override', 0);

		// Do not allow template override
		if (!$allow_override) {
			// Set our template as first choice
			if ( isset($this->_path['template']) && is_array($this->_path['template']) ) {
				foreach ($this->_path['template'] as $key=>$path) {
					if (stristr($path, 'com_ajaxregister')) {
						$this->_path['template'][0] = $path;
						break;
					}
				}
			}
		}

		parent::display($tpl);
	}
}
?>